@@ -1117,7 +1117,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, context)
     {
       case 5: /* "KEYWORD" */
 #line 118 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
-	{ igraph_Free((yyvaluep->str).s); };
+	{ IGRAPH_FREE((yyvaluep->str).s); };
 #line 1122 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
 	break;
       case 12: /* "list" */
@@ -1132,12 +1132,12 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, context)
 	break;
       case 14: /* "key" */
 #line 118 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
-	{ igraph_Free((yyvaluep->str).s); };
+	{ IGRAPH_FREE((yyvaluep->str).s); };
 #line 1137 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
 	break;
       case 16: /* "string" */
 #line 118 "/Users/tamas/dev/igraph/igraph/src/io/gml-parser.y"
-	{ igraph_Free((yyvaluep->str).s); };
+	{ IGRAPH_FREE((yyvaluep->str).s); };
 #line 1142 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/gml-parser.c"
 	break;
 
@@ -1755,7 +1755,7 @@ int igraph_gml_yyerror(YYLTYPE* locp, igraph_i_gml_parsedata_t *context,
 
 void igraph_i_gml_get_keyword(char *s, int len, void *res) {
   struct { char *s; int len; } *p=res;
-  p->s=igraph_Calloc(len+1, char);
+  p->s=IGRAPH_CALLOC(len+1, char);
   if (!p->s) { 
     igraph_error("Cannot read GML file", IGRAPH_FILE_BASENAME, __LINE__, IGRAPH_PARSEERROR);
   }
@@ -1766,7 +1766,7 @@ void igraph_i_gml_get_keyword(char *s, int len, void *res) {
 
 void igraph_i_gml_get_string(char *s, int len, void *res) {
   struct { char *s; int len; } *p=res;
-  p->s=igraph_Calloc(len-1, char);
+  p->s=IGRAPH_CALLOC(len-1, char);
   if (!p->s) { 
     igraph_error("Cannot read GML file", IGRAPH_FILE_BASENAME, __LINE__, IGRAPH_PARSEERROR);
   }
@@ -1785,7 +1785,7 @@ double igraph_i_gml_get_real(char *s, int len) {
 } 
 
 igraph_gml_tree_t *igraph_i_gml_make_numeric(char* s, int len, double value) {
-  igraph_gml_tree_t *t = igraph_Calloc(1, igraph_gml_tree_t);
+  igraph_gml_tree_t *t = IGRAPH_CALLOC(1, igraph_gml_tree_t);
 
   if (!t) { 
     igraph_error("Cannot build GML tree", IGRAPH_FILE_BASENAME, __LINE__, IGRAPH_ENOMEM);
@@ -1809,7 +1809,7 @@ igraph_gml_tree_t *igraph_i_gml_make_numeric(char* s, int len, double value) {
 
 igraph_gml_tree_t *igraph_i_gml_make_numeric2(char* s, int len, 
                                               char* v, int vlen) {
-  igraph_gml_tree_t *t = igraph_Calloc(1, igraph_gml_tree_t);
+  igraph_gml_tree_t *t = IGRAPH_CALLOC(1, igraph_gml_tree_t);
   char tmp = v[vlen];
 
   if (!t) { 
@@ -1851,7 +1851,7 @@ igraph_gml_tree_t *igraph_i_gml_make_numeric2(char* s, int len,
 
 igraph_gml_tree_t *igraph_i_gml_make_string(char* s, int len, 
                                             char *value, int valuelen) {
-  igraph_gml_tree_t *t = igraph_Calloc(1, igraph_gml_tree_t);
+  igraph_gml_tree_t *t = IGRAPH_CALLOC(1, igraph_gml_tree_t);
 
   if (!t) { 
     igraph_error("Cannot build GML tree", IGRAPH_FILE_BASENAME, __LINE__, IGRAPH_ENOMEM);
@@ -1873,7 +1873,7 @@ igraph_gml_tree_t *igraph_i_gml_make_string(char* s, int len,
 igraph_gml_tree_t *igraph_i_gml_make_list(char* s, int len, 
                                           igraph_gml_tree_t *list) {
   
-  igraph_gml_tree_t *t=igraph_Calloc(1, igraph_gml_tree_t);
+  igraph_gml_tree_t *t=IGRAPH_CALLOC(1, igraph_gml_tree_t);
 
   if (!t) { 
     igraph_error("Cannot build GML tree", IGRAPH_FILE_BASENAME, __LINE__, IGRAPH_ENOMEM);
@@ -1891,7 +1891,7 @@ igraph_gml_tree_t *igraph_i_gml_make_list(char* s, int len,
 igraph_gml_tree_t *igraph_i_gml_merge(igraph_gml_tree_t *t1, igraph_gml_tree_t* t2) {
 
   igraph_gml_tree_mergedest(t1, t2);
-  igraph_Free(t2);
+  IGRAPH_FREE(t2);
 
   return t1;
 }
